# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel


class RunTaskResponse(UniversalBaseModel):
    """
    Response model for task execution.
    """

    error: typing.Optional[str] = pydantic.Field(default=None)
    """
    Error message if failed
    """

    error_type: typing.Optional[str] = pydantic.Field(default=None)
    """
    Error type: 'timeout', 'execution_error', 'not_found', 'validation_error'
    """

    job_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Windmill job ID for debugging
    """

    result: typing.Optional[typing.Optional[typing.Any]] = pydantic.Field(default=None)
    """
    The task result
    """

    success: bool = pydantic.Field()
    """
    Whether execution succeeded
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
